import codecs
import os

from setuptools import find_packages, setup

STATIC_HOST = "gpt4free.github.io"

here = os.path.abspath(os.path.dirname(__file__))

INSTALL_REQUIRE = [
    "requests",
    "aiohttp",
    "brotli",
    "pycryptodome",
    "nest_asyncio",
]

EXTRA_REQUIRE = {
    'all': [
        "curl_cffi>=0.6.2",
        "certifi",
        "browser_cookie3",         # get_cookies
        "duckduckgo-search>=5.0",  # internet.search
        "beautifulsoup4",          # internet.search and bing.create_images
        "platformdirs",
        "aiohttp_socks",           # proxy
        "pillow",                  # image
        "cairosvg",                # svg image
        "werkzeug", "flask",       # gui
        "fastapi",                 # api
        "uvicorn",                 # api
        "nodriver",
        "python-multipart",
        "pywebview",
        "plyer",
        "setuptools",
        "odfpy", # files
        "ebooklib",
        "openpyxl",
        "markitdown[all]"
    ],
    'slim': [
        "curl_cffi>=0.6.2",
        "certifi",
        "browser_cookie3",
        "duckduckgo-search>=5.0"  ,# internet.search
        "beautifulsoup4",          # internet.search and bing.create_images
        "aiohttp_socks",           # proxy
        "pillow",                  # image
        "werkzeug", "flask",       # gui
        "fastapi",                 # api
        "uvicorn",                 # api
        "python-multipart",
        "markitdown[pdf, docx, pptx]"
    ],
    "image": [
        "pillow",
        "cairosvg",
        "beautifulsoup4"
    ],
    "webview": [
        "pywebview",
        "platformdirs",
        "plyer",
        "cryptography",
    ],
    "api": [
        "loguru", "fastapi",
        "uvicorn",
        "python-multipart",
    ],
    "gui": [
        "werkzeug", "flask",
        "beautifulsoup4", "pillow",
        "duckduckgo-search>=5.0",
    ],
    "search": [
        "beautifulsoup4",
        "pillow",
        "duckduckgo-search>=5.0",
    ],
    "local": [
        "gpt4all"
    ],
    "files": [
        "beautifulsoup4",
        "odfpy",
        "ebooklib",
        "openpyxl",
        "markitdown[all]"
    ]
}

DESCRIPTION = (
    'A free and open source API for accessing various large language models'
)

# Setting up
setup(
    name='buggpt',
    version='0.0.1', # Hardcoded version for PyPI upload
    author='Tekky', # Keep author name as is
    author_email='<support@buggpt.ai>', # Changed email
    description='A free and open source API for accessing various large language models', # Updated description
    long_description="", # Set long_description to empty
    long_description_content_type='text/plain', # Changed content type to plain
    packages=find_packages(),
    package_data={
        'buggpt': ['buggpt/interference/*', 'buggpt/gui/client/*', 'buggpt/gui/server/*', 'buggpt/Provider/npm/*', 'buggpt/local/models/*'] # Changed package data path
    },
    include_package_data=True,
    install_requires=INSTALL_REQUIRE,
    extras_require=EXTRA_REQUIRE,
    entry_points={
        'console_scripts': ['buggpt=buggpt.cli:main'], # Changed console script name and path
    },
    url='https://github.com/yourusername/buggpt',  # Placeholder for new GitHub repository
    project_urls={
        'Source Code': 'https://github.com/yourusername/buggpt',  # Placeholder for new GitHub repository
        'Bug Tracker': 'https://github.com/yourusername/buggpt/issues',  # Placeholder for new issue tracker
    },
    keywords=[
        'python',
        'chatbot',
        'reverse-engineering',
        'openai',
        'chatbots',
        'gpt',
        'language-model',
        'gpt-3',
        'gpt3',
        'openai-api',
        'gpt-4',
        'gpt4',
        'chatgpt',
        'chatgpt-api',
        'openai-chatgpt',
        'chatgpt-free',
        'chatgpt-4',
        'chatgpt4',
        'chatgpt4-api',
        'free',
        'free-gpt',
        'buggpt', # Changed keyword
    ],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Operating System :: Unix',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
    ],
)
